// -*- c++ -*-
/* $Id: init.cc,v 1.2 2003/03/23 13:10:54 murrayc Exp $ */

/* init.cc
 *
 * Copyright 2001      Free Software Foundation
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <libgnomevfsmm/init.h>
#include <libgnomevfsmm/wrap_init.h>
#include <glibmm/init.h>
#include <libgnomevfsmmconfig.h> //For LIBGNOMEVFSMM_VERSION
#include <libgnomevfs/gnome-vfs-init.h>

namespace Gnome
{

namespace Vfs
{

void init()
{
  Glib::init(); //Sets up the g type system and the Glib::wrap() table.
  wrap_init(); //Tells the Glib::wrap() table about the libgnomecanvasmm classes.
  gnome_vfs_init();
}

} //namespace Vfs
} //namespace Gnome
